@@ -1,21 +1,24 @@
 import datetime
-from typing import List, Optional
+from typing import Optional
 from urllib.parse import urlparse
 
 import requests
 from influxdb_client import InfluxDBClient
 from influxdb_client.client.write_api import SYNCHRONOUS
+from peewee import fn
 
 from robotoff import settings
+from robotoff.models import ProductInsight, with_db
 from robotoff.utils import get_logger, http_session
 
 logger = get_logger(__name__)
 
-URL_PATHS: List[str] = [
+URL_PATHS: list[str] = [
     "/ingredients-analysis?json=1",
     "/data-quality?json=1",
     "/ingredients?stats=1&json=1",
     "/states?json=1",
+    "/misc?json=1",
 ]
 
 COUNTRY_TAGS = [
@@ -142,8 +145,8 @@ def generate_metrics_from_path(
     target_datetime: datetime.datetime,
     count: Optional[int] = None,
     facet: Optional[str] = None,
-) -> List:
-    inserts: List = []
+) -> list[dict]:
+    inserts: list[dict] = []
     url = settings.BaseURLProvider().country(country_tag + "-en").get() + path
 
     if facet is None:
@@ -192,3 +195,52 @@ def generate_metrics_from_path(
             }
         )
     return inserts
+
+
+def save_insight_metrics():
+    """Save number of insights, grouped by the following fields:
+    - type
+    - annotation
+    - automatic_processing
+    - predictor
+    - reserved_barcode
+    """
+    target_datetime = datetime.datetime.now()
+
+    if (client := get_influx_client()) is not None:
+        write_client = client.write_api(write_options=SYNCHRONOUS)
+        inserts = generate_insight_metrics(target_datetime)
+        write_client.write(bucket=settings.INFLUXDB_BUCKET, record=inserts)
+
+
+@with_db
+def generate_insight_metrics(target_datetime: datetime.datetime) -> list[dict]:
+    group_by_fields = [
+        ProductInsight.type,
+        ProductInsight.annotation,
+        ProductInsight.automatic_processing,
+        ProductInsight.predictor,
+        ProductInsight.reserved_barcode,
+    ]
+    inserts = []
+    query_results = (
+        ProductInsight.select(
+            *group_by_fields,
+            fn.COUNT(ProductInsight.id).alias("count"),
+        )
+        .group_by(*group_by_fields)
+        .dicts()
+    )
+    total_count = sum(query_result["count"] for query_result in query_results)
+
+    for query_result in query_results:
+        count = query_result.pop("count")
+        inserts.append(
+            {
+                "measurement": "insights",
+                "tags": query_result,
+                "time": target_datetime.isoformat(),
+                "fields": {"count": count, "percent": count / total_count},
+            }
+        )
+    return inserts
